export declare type Schema = Record<string, unknown>;
export declare type SchemaType = 'string' | 'number' | 'integer' | 'object' | 'array' | 'boolean';
export declare type SchemaTypeOption = {
    value: SchemaType;
    label: string;
};
export declare type CommonSchemaField = 'description';
export declare type StringSchemaField = CommonSchemaField | 'enum' | 'minLength' | 'maxLength' | 'pattern' | 'format';
export declare type NumberSchemaField = CommonSchemaField | 'minimum' | 'maximum' | 'multipleOf';
export declare type IntegerSchemaField = CommonSchemaField | 'minimum' | 'maximum' | 'multipleOf';
export declare type BoolSchemaField = CommonSchemaField;
export declare type ObjectSchemaField = CommonSchemaField | 'required';
export declare type ArraySchemaField = CommonSchemaField | 'uniqueItems' | 'minItems' | 'maxItems';
export declare type SchemaFieldOptionType = 'text' | 'number' | 'boolean' | 'multi_creatable' | 'select' | 'required';
export declare type CommonValidSchemaField = CommonSchemaField | 'title' | 'type';
export declare type StringValidSchemaField = StringSchemaField | CommonValidSchemaField;
export declare type NumberValidSchemaField = NumberSchemaField | CommonValidSchemaField;
export declare type IntegerValidSchemaField = IntegerSchemaField | CommonValidSchemaField;
export declare type BoolValidSchemaField = BoolSchemaField | CommonValidSchemaField;
export declare type ArrayValidSchemaField = ArraySchemaField | CommonValidSchemaField | 'items';
export declare type ObjectValidSchemaField = ObjectSchemaField | CommonValidSchemaField | 'properties';
export declare type SchemaFieldOption = {
    label: string;
    type: SchemaFieldOptionType;
    optionList?: any;
};
export declare type CommonSchemaFieldOption = SchemaFieldOption & {
    value: CommonSchemaField;
};
export declare type StringSchemaFieldOption = SchemaFieldOption & {
    value: StringSchemaField;
};
export declare type NumberSchemaFieldOption = SchemaFieldOption & {
    value: NumberSchemaField;
};
export declare type IntegerSchemaFieldOption = SchemaFieldOption & {
    value: IntegerSchemaField;
};
export declare type BoolSchemaFieldOption = SchemaFieldOption & {
    value: BoolSchemaField;
};
export declare type ObjectSchemaFieldOption = SchemaFieldOption & {
    value: ObjectSchemaField;
};
export declare type ArraySchemaFieldOption = SchemaFieldOption & {
    value: ArraySchemaField;
};
export declare type SchemaMenuOption = StringSchemaFieldOption | NumberSchemaFieldOption | IntegerSchemaFieldOption | BoolSchemaFieldOption | ObjectSchemaFieldOption | ArraySchemaFieldOption;
